Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(182)

Unified Diff: tools/perf/page_sets/system_health/searching_stories.py

Issue 2888133002: Modify list_system_health_stories to generate_system_health_csv (Closed)
Patch Set: Address Juan's comments Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/perf/page_sets/system_health/searching_stories.py
diff --git a/tools/perf/page_sets/system_health/searching_stories.py b/tools/perf/page_sets/system_health/searching_stories.py
index bdbc0460d4290e284179d56ad92633941e4f491e..ea0c41ba0ae053c10d9a3e7e83e1e087ce2a396e 100644
--- a/tools/perf/page_sets/system_health/searching_stories.py
+++ b/tools/perf/page_sets/system_health/searching_stories.py
@@ -13,6 +13,13 @@ from devil.android.sdk import keyevent # pylint: disable=import-error
# TODO(ssid): Rename the search stories to browse stories crbug.com/708300.
class SearchGoogleStory(system_health_story.SystemHealthStory):
+ """ A typical Google search user story.
+ Issue the search query "what is science" in the search box and press Enter.
+ Wait for the search result page to be loaded, then scroll to the Wikipedia
+ result.
+ Navigate to wikipedia page by clicking on the result and wait for it to be
+ fully loaded.
+ """
NAME = 'search:portal:google'
URL = 'https://www.google.co.uk/'
TAGS = [story_tags.EMERGING_MARKET]
@@ -74,12 +81,18 @@ class SearchOmniboxStory(system_health_story.SystemHealthStory):
class MobileNewTabPageStory(system_health_story.SystemHealthStory):
"""Story that loads new tab page and performs searches.
For each of the search queries in |_SEARCH_TEXTS| below, this story does:
perezju 2017/05/19 13:48:29 nit: "in in" -> "in"
nednguyen 2017/05/19 15:07:50 Done.
- enter the search query on the new tab page search box
- read results
- navigates back to new tab page
- """
+ List of search queries:
+ 'does google know everything',
+ 'most famous paintings',
+ 'current weather',
+ 'best movies 2016',
+ 'how to tie a tie'
perezju 2017/05/19 13:48:29 I'm not very happy about duplicating this list her
nednguyen 2017/05/19 15:07:50 I removed the duplicating list for now.
+ """
NAME = 'browse:chrome:newtab'
URL = 'chrome://newtab'
_SEARCH_TEXTS = ['does google know everything',
@@ -74,12 +81,18 @@ class SearchOmniboxStory(system_health_story.SystemHealthStory):
class MobileNewTabPageStory(system_health_story.SystemHealthStory):
"""Story that loads new tab page and performs searches.
- For each of the search queries in |_SEARCH_TEXTS| below, this story does:
+ For each of the search queries in in the list below, this story does:
perezju 2017/05/19 13:48:29 nit: "in in" -> "in"
nednguyen 2017/05/19 15:07:50 Done.

Powered by Google App Engine
This is Rietveld 408576698